(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    175344,       4041]
NotebookOptionsPosition[    163849,       3816]
NotebookOutlinePosition[    167473,       3893]
CellTagsIndexPosition[    167430,       3890]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["---Preamble", "Title",
 CellChangeTimes->{{3.7069489383059444`*^9, 3.7069489441945896`*^9}}],

Cell[CellGroupData[{

Cell["Load LieAnalysis` package", "Section",
 CellChangeTimes->{{3.7069489478744135`*^9, 3.706948955634028*^9}}],

Cell[BoxData[{
 RowBox[{"<<", " ", "LieAnalysis`"}], "\n", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"SetOptions", "[", 
     RowBox[{"Compile", ",", " ", 
      RowBox[{"CompilationTarget", " ", "->", " ", "\"\<C\>\""}]}], "]"}], 
    ";"}], 
   RowBox[{"(*", 
    RowBox[{"For", " ", "faster", " ", "upwind", " ", "algorithm"}], "*)"}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.7069486444423294`*^9, 3.7069486458069487`*^9}, {
  3.7069489575902653`*^9, 3.7069489674093485`*^9}, {3.7083439217665043`*^9, 
  3.7083439234777136`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"3fc1d014-3a54-4492-b5b1-4a5fbdf8af73"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["---Functions", "Title",
 CellChangeTimes->{{3.7069489710420465`*^9, 3.7069489714100237`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Initialization and helper functions for wavefront propagation\
\>", "Section"],

Cell[CellGroupData[{

Cell["Initialize distance volume", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OSInitialVolume", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Nx_", ",", "Ny_", ",", "N\[Theta]_"}], "}"}], ",", "g0d_", ",",
      "periodicity_"}], "]"}], ":=", 
   RowBox[{"Module", "[", "\n", "\t", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g0dList", ",", 
       RowBox[{"dims", "=", 
        RowBox[{"{", 
         RowBox[{"Nx", ",", "Ny", ",", "N\[Theta]"}], "}"}]}], ",", "W"}], 
      "}"}], "\n", "\t", ",", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "The", " ", "user", " ", "provides", " ", "a", " ", "seed", " ", 
        "point"}], ",", " ", 
       RowBox[{
       "or", " ", "a", " ", "list", " ", "of", " ", "seed", " ", "points"}]}],
       "*)"}], "\n", "\t", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Dimensions", "[", "g0d", "]"}], "==", 
         RowBox[{"{", "3", "}"}]}], ",", 
        RowBox[{"g0dList", "=", 
         RowBox[{"{", "g0d", "}"}]}], ",", 
        RowBox[{
         RowBox[{"g0dList", "=", "g0d"}], ";"}]}], "]"}], ";", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{"Initialize", " ", "with", " ", "ones"}], "*)"}], "\n", "\t", 
      RowBox[{"W", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"1.", ",", "dims"}], "]"}]}], ";", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{
       "Place", " ", "a", " ", "zero", " ", "at", " ", "every", " ", "seed", 
        " ", "point", " ", "location"}], "*)"}], "\n", "\t", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"W", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"g0dList", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{"g0dList", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
            RowBox[{"g0dList", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}], "]"}], "=", 
         "0."}], "\n", "\t\t", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "g0dList", "]"}], ",", "1"}], "}"}]}], "]"}],
       ";", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{"Return", " ", "distance", " ", "volume", " ", "W"}], "*)"}], 
      "\n", "\t", 
      RowBox[{"Return", "[", 
       RowBox[{"ObjPositionOrientationData", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<Data\>\"", "->", "W"}], ",", 
          RowBox[{"\"\<Symmetry\>\"", "->", "periodicity"}]}], "}"}], "]"}], 
       "]"}]}]}], "\n", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.768620414842098*^9, 3.768620415782893*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"2ce70a5e-a2f4-4dd1-903a-b9900d162b3d"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dealing with boundary conditions (Reflective padding)", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Function", " ", "for", " ", "padding", " ", "with", " ", "the", " ", 
    "maximum", " ", "value"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"OSSpatialPadding", "[", 
      RowBox[{
       RowBox[{"os_", "/;", 
        RowBox[{"ValidQ", "[", 
         RowBox[{"os", ",", "ObjPositionOrientationData"}], "]"}]}], ",", 
       RowBox[{"padsize_", " ", "/;", " ", 
        RowBox[{"MatchQ", "[", 
         RowBox[{"padsize", ",", "_Integer"}], "]"}]}]}], "]"}], ":=", 
     RowBox[{"Module", "[", "\n", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"osData", "=", 
         RowBox[{"os", "[", "\"\<Data\>\"", "]"}]}], "}"}], "\n", "\t", ",", 
       "\n", "\t", 
       RowBox[{
        RowBox[{"osData", "=", 
         RowBox[{"PadLeft", "[", 
          RowBox[{"osData", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "osData", "]"}], "+", 
            RowBox[{"{", 
             RowBox[{"padsize", ",", "padsize", ",", "0"}], "}"}]}], ",", 
           RowBox[{"Max", "[", "osData", "]"}]}], "]"}]}], ";", "\n", "\t", 
        RowBox[{"osData", "=", 
         RowBox[{"PadRight", "[", 
          RowBox[{"osData", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "osData", "]"}], "+", 
            RowBox[{"{", 
             RowBox[{"padsize", ",", "padsize", ",", "0"}], "}"}]}], ",", 
           RowBox[{"Max", "[", "osData", "]"}]}], "]"}]}], ";", "\n", "\t", 
        RowBox[{"Return", "[", 
         RowBox[{"Affix", "[", 
          RowBox[{"os", ",", 
           RowBox[{"\"\<Data\>\"", "->", "osData"}]}], "]"}], "]"}]}]}], "\n",
       "]"}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
    "Function", " ", "for", " ", "filling", " ", "the", " ", "padded", " ", 
     "region", " ", "with", " ", "reflected", " ", "values"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"OSReflectPaddedRegion", "[", 
      RowBox[{
       RowBox[{"os_", "/;", 
        RowBox[{"ValidQ", "[", 
         RowBox[{"os", ",", "ObjPositionOrientationData"}], "]"}]}], ",", 
       RowBox[{"padsize_", " ", "/;", " ", 
        RowBox[{"MatchQ", "[", 
         RowBox[{"padsize", ",", "_Integer"}], "]"}]}]}], "]"}], ":=", 
     RowBox[{"Module", "[", "\n", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"osData", "=", 
         RowBox[{"os", "[", "\"\<Data\>\"", "]"}]}], "}"}], "\n", "\t", ",", 
       "\n", "\t", 
       RowBox[{"Return", "[", 
        RowBox[{"Affix", "[", 
         RowBox[{"os", ",", 
          RowBox[{"\"\<Data\>\"", "->", 
           RowBox[{"ReflectPaddedRegion", "[", 
            RowBox[{"osData", ",", "padsize"}], "]"}]}]}], "]"}], "]"}]}], 
      "\n", "]"}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
    "The", " ", "compiled", " ", "function", " ", "for", " ", "reflection", 
     " ", "padding"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"ReflectPaddedRegion", "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Uin", ",", "_Real", ",", "3"}], "}"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"in", " ", 
             RowBox[{"(", 
              RowBox[{"x", ",", "y", ",", "theta"}], ")"}]}], "-", 
            "formatting"}], ")"}], "*)"}], ",", 
         RowBox[{"{", 
          RowBox[{"padsize", ",", "_Integer"}], "}"}]}], "}"}], ",", "\n", 
       "\t", 
       RowBox[{"Module", "[", "\n", "\t\t", 
        RowBox[{
         RowBox[{"{", "\n", "\t\t\t", 
          RowBox[{"U", "=", "Uin"}], "\n", "\t\t", "}"}], "\n", "\t\t", ",", 
         "\n", "\t\t", 
         RowBox[{
          RowBox[{"Do", "[", 
           RowBox[{"(*", 
            RowBox[{"Reflect", " ", "boundary"}], "*)"}], "\n", "\t\t\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Do", "[", "\n", "\t\t\t\t", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"padsize", "-", "i", "+", "1"}], ")"}]}], ",", 
                    "All", ",", "All"}], "]"}], "]"}], "=", 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"padsize", "+", "i", "+", "1"}], ")"}]}], ",", 
                    "All", ",", "All"}], "]"}], "]"}]}], ";", 
                RowBox[{"(*", 
                 RowBox[{"Bottom", " ", "boundary"}], "*)"}], "\n", 
                "\t\t\t\t", 
                RowBox[{
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"padsize", "-", "i", "+", "1"}], ")"}], ",", 
                    "All", ",", "All"}], "]"}], "]"}], "=", 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"padsize", "+", "i", "+", "1"}], ")"}], ",", 
                    "All", ",", "All"}], "]"}], "]"}]}], ";", 
                RowBox[{"(*", 
                 RowBox[{"Top", " ", "boundary"}], "*)"}], "\n", "\t\t\t\t", 
                RowBox[{
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", 
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"padsize", "-", "i", "+", "1"}], ")"}]}], ",", 
                    "All"}], "]"}], "]"}], "=", 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", 
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"padsize", "+", "i", "+", "1"}], ")"}]}], ",", 
                    "All"}], "]"}], "]"}]}], ";", 
                RowBox[{"(*", 
                 RowBox[{"Right", " ", "boundary"}], "*)"}], "\n", "\t\t\t\t", 
                RowBox[{
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", 
                    RowBox[{"(", 
                    RowBox[{"padsize", "-", "i", "+", "1"}], ")"}], ",", 
                    "All"}], "]"}], "]"}], "=", 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", 
                    RowBox[{"(", 
                    RowBox[{"padsize", "+", "i", "+", "1"}], ")"}], ",", 
                    "All"}], "]"}], "]"}]}], ";"}], 
               RowBox[{"(*", 
                RowBox[{"Left", " ", "boundary"}], "*)"}], "\n", "\t\t\t", 
               ",", "\n", "\t\t\t\t", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", "padsize"}], "}"}]}], "\n", 
              "\t\t\t", "]"}], ";"}], "\n", "\t\t", ",", "\n", "\t\t\t", 
            RowBox[{"{", "2", "}"}]}], "\n", "\t\t", "]"}], ";", 
          RowBox[{"(*", 
           RowBox[{
           "Do", " ", "this", " ", "twice", " ", "to", " ", "fill", " ", 
            "the", " ", "diagonal", " ", "padded", " ", "elements", " ", 
            "properly"}], "*)"}], "\n", "\t\t", 
          RowBox[{"Return", "[", "U", "]"}]}]}], "\n", "\t", "]"}]}], "\n", 
      "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7686204205948973`*^9, 3.7686204280331354`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"d25c5248-bc1a-47ed-ad1a-5b02a02e76d6"]
}, Closed]],

Cell[CellGroupData[{

Cell["Upwind finite differences", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"AiWmin", ",", 
       RowBox[{"-", "AiWplus"}], ",", "0"}], "]"}], " ", "with", " ", 
     "AiWmin", " ", "the", " ", "backward", " ", "difference", " ", "of", " ",
      "W", " ", "in", " ", "Ai", " ", "direction"}], ",", " ", 
    RowBox[{
    "and", " ", "AiWplus", " ", "the", " ", "forward", " ", "difference"}]}], 
   "*)"}], "\n", 
  RowBox[{
   RowBox[{"UpwindDifferences", "[", 
    RowBox[{"AiWmin_", ",", "AiWplus_"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "=", 
        RowBox[{"Clip", "[", 
         RowBox[{"AiWmin", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Infinity]"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"b", "=", 
        RowBox[{"Clip", "[", 
         RowBox[{
          RowBox[{"-", "AiWplus"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Infinity]"}], "}"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"a", "+", 
      RowBox[{"Clip", "[", 
       RowBox[{
        RowBox[{"b", "-", "a"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "\[Infinity]"}], "}"}]}], "]"}]}]}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"e95d1627-6a0a-4b05-88b8-15cdd3ec1623"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dynamic update visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Dynamic report update", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SE2NSolvePDEDynamicStatus", "[", "]"}], ":=", 
  RowBox[{"Module", "[", "\n", "\t", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t", 
    RowBox[{
     RowBox[{"SE2PDE`dynamicUpdate", "=", "True"}], ";", "\n", "\t", 
     RowBox[{"SE2PDE`W", "=", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"{", "0.", "}"}], "}"}], "}"}]}], ";", "\n", "\t", 
     RowBox[{"SE2PDE`Hmax", "=", "1."}], ";", "\n", "\t", 
     RowBox[{"Dynamic", "@", 
      RowBox[{"Column", "[", 
       RowBox[{
        RowBox[{"{", "\n", "\t\t", 
         RowBox[{
          RowBox[{"Dynamic", "@", 
           RowBox[{"Row", "@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<---------   Max[Abs[hamiltonian]]: \>\"", ",", 
              "SE2PDE`Hmax", ",", "\"\<   ---------\>\""}], "}"}]}]}], ",", 
          "\n", "\t\t", 
          RowBox[{"Row", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", "\"\<Volume renderling\>\""}], "]"}], "&"}],
               "@", 
              RowBox[{"Framed", "@", 
               RowBox[{"Dynamic", "@", 
                RowBox[{"ImageAdjust", "@", 
                 RowBox[{"Image3D", "[", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"Transpose", "[", 
                    RowBox[{"SE2PDE`W", ",", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}]}], ",", 
                   RowBox[{"ImageSize", "->", 
                    RowBox[{"{", 
                    RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}]}]}]}]}], 
             ",", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", "\"\<Integral over theta\>\""}], "]"}], 
               "&"}], "@", 
              RowBox[{"Framed", "@", 
               RowBox[{"Dynamic", "@", 
                RowBox[{"ImageAdjust", "@", 
                 RowBox[{"Image", "[", 
                  RowBox[{
                   RowBox[{"Map", "[", 
                    RowBox[{"Total", ",", "SE2PDE`W", ",", 
                    RowBox[{"{", "2", "}"}]}], "]"}], ",", 
                   RowBox[{"ImageSize", "->", 
                    RowBox[{"{", 
                    RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}]}]}]}]}], 
             ",", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{
                "#", ",", "\"\<Minimum intensity projection over theta\>\""}],
                 "]"}], "&"}], "@", 
              RowBox[{"Framed", "@", 
               RowBox[{"Dynamic", "@", 
                RowBox[{"ImageAdjust", "@", 
                 RowBox[{"Image", "[", 
                  RowBox[{
                   RowBox[{"Map", "[", 
                    RowBox[{"Min", ",", "SE2PDE`W", ",", 
                    RowBox[{"{", "2", "}"}]}], "]"}], ",", 
                   RowBox[{"ImageSize", "->", 
                    RowBox[{"{", 
                    RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}]}]}]}]}]}], 
            "}"}]}]}], "\n", "\t", "}"}], ",", "\"\<Center\>\""}], 
       "]"}]}]}]}], "\n", "]"}]}]], "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"530fac99-326c-4ce2-9483-27ae2aa071d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Turn off dynamic updating", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SE2NSolvePDEDynamicStatusOff", "[", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"SE2PDE`dynamicUpdate", "=", "False"}], ";"}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[8]:=",ExpressionUUID->"43bf2da6-9a42-41b3-8e33-f9c9c22b1cad"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Main I: Sub-Riemannian wavefront propagation", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SRWaveFrontPropagation", "[", 
   RowBox[{
   "W0_", ",", "cost_", ",", "g0d_", ",", "\[Xi]_", ",", "\[Epsilon]_", ",", 
    "sTheta_", ",", "sx_", ",", "itMax_", ",", "onlyForwardGearQ_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\n", "\t", 
   RowBox[{
    RowBox[{"{", "\n", "\t\t", 
     RowBox[{
      RowBox[{"W", "=", "W0"}], ",", "\n", "\t\t", "g0dList", ",", "\n", 
      "\t\t", "WPadded", ",", "costPadded", ",", "\n", "\t\t", "H", ",", 
      "Hmax", ",", "\n", "\t\t", "startComputingDerivatives", ",", "\n", 
      "\t\t", "A1Wplus", ",", "A1Wmin", ",", 
      RowBox[{"(*", 
       RowBox[{"A1", " ", "is", " ", "spatial", " ", "forward", " ", 
        RowBox[{"(", "\[Xi]", ")"}]}], "*)"}], "\n", "\t\t", "A2Wplus", ",", 
      "A2Wmin", ",", 
      RowBox[{"(*", 
       RowBox[{"A2", " ", "is", " ", "spatial", " ", "sideways", " ", 
        RowBox[{"(", "\[Eta]", ")"}]}], "*)"}], "\n", "\t\t", "A3Wplus", ",", 
      "A3Wmin", ",", 
      RowBox[{"(*", 
       RowBox[{"A3", " ", "is", " ", "orientation", " ", "direction", " ", 
        RowBox[{"(", "\[Theta]", ")"}]}], "*)"}], "\n", "\t\t", "A1Wsquared", 
      ",", "A2Wsquared", ",", "A3Wsquared", ",", "\n", "\t\t", 
      RowBox[{"it", "=", "1"}], ",", "\n", "\t\t", 
      RowBox[{"padsize", "=", "3"}], ",", "\n", "\t\t", 
      RowBox[{"deltat", "=", 
       RowBox[{"0.25", 
        RowBox[{"Min", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"sx", "*", "\[Xi]"}], ",", 
           RowBox[{"sx", "*", 
            RowBox[{"\[Xi]", "/", "\[Epsilon]"}]}], ",", "1"}], "}"}], 
         "]"}]}]}]}], "\n", "\t", "}"}], ",", "\n", "\t", "\n", "\t", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{
      "The", " ", "user", " ", "provides", " ", "a", " ", "seed", " ", 
       "point"}], ",", " ", 
      RowBox[{
      "or", " ", "a", " ", "list", " ", "of", " ", "seed", " ", "points"}]}], 
     "*)"}], "\n", "\t", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Dimensions", "[", "g0d", "]"}], "==", 
        RowBox[{"{", "3", "}"}]}], ",", 
       RowBox[{"g0dList", "=", 
        RowBox[{"{", "g0d", "}"}]}], ",", 
       RowBox[{
        RowBox[{"g0dList", "=", "g0d"}], ";"}]}], "]"}], ";", "\n", "\t", 
     "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
         "**", "**", "**", "**", "**"}], "*", "Pad", " ", "input"}], "*)"}], 
     "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
      "The", " ", "padded", " ", "regions", " ", "are", " ", "later", " ", 
       "used", " ", "to", " ", "reflect", " ", "the", " ", "original", " ", 
       "data"}], "*)"}], "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "Pad", " ", "U", " ", "with", " ", "3", " ", "elements", " ", "on", 
        " ", "each", " ", 
        RowBox[{"side", ".", " ", "I"}], " ", "choose", " ", "three", " ", 
        "because", " ", "the", " ", "finit", " ", "difference", " ", "scheme",
         " ", "uses", " ", "third", " ", "order", " ", "B"}], "-", 
       RowBox[{"Spline", " ", "interpolation"}]}], "*)"}], "\n", "\t", 
     RowBox[{"WPadded", "=", 
      RowBox[{"OSSpatialPadding", "[", 
       RowBox[{"W", ",", "padsize"}], "]"}]}], ";", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"Pad", " ", "cost"}], "*)"}], "\n", "\t", 
     RowBox[{"costPadded", "=", 
      RowBox[{"OSSpatialPadding", "[", 
       RowBox[{"cost", ",", "padsize"}], "]"}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
         "**", "**", "**", "**", "**", "**", "Evolving"}], " ", "W"}], "*)"}],
      "\n", "\t", 
     RowBox[{"H", "=", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"1.", ",", 
        RowBox[{"Dimensions", "[", "WPadded", "]"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"Hmax", "=", "1."}], ";", 
     RowBox[{"it", "=", "1"}], ";", "\n", "\t", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Hmax", ">", 
         RowBox[{"(", 
          RowBox[{"10.", "^", 
           RowBox[{"(", 
            RowBox[{"-", "4"}], ")"}]}], ")"}]}], "&&", 
        RowBox[{"it", "<", "itMax"}]}], ",", 
       RowBox[{"(*", 
        RowBox[{
        "While", " ", "the", " ", "maximum", " ", "change", " ", "is", " ", 
         "still", " ", "larger", " ", "then", " ", "0.000001"}], "*)"}], "\n",
        "\t\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**", "**", "**", "**", "**", "**", "**", "**"}], "*", 
         "Reflect", " ", "image", " ", "boundaries"}], "*)"}], "\n", "\t\t", 
       RowBox[{
        RowBox[{"WPadded", "=", 
         RowBox[{"OSReflectPaddedRegion", "[", 
          RowBox[{"WPadded", ",", "padsize"}], "]"}]}], ";", "\n", "\t\t", 
        "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
          "*", "Calculate", " ", "derivatives"}], "*)"}], "\n", "\t\t", 
        RowBox[{"Label", "[", "startComputingDerivatives", "]"}], ";", "\n", 
        "\t\t", 
        RowBox[{"Quiet", "[", "\n", "\t\t\t", 
         RowBox[{
          RowBox[{"Check", "[", "\n", "\t\t\t\t", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"A1Wplus", ",", "A2Wplus", ",", "A3Wplus"}], "}"}], 
              "=", 
              RowBox[{"LeftInvariantDerivatives", "[", 
               RowBox[{"WPadded", ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
                RowBox[{"\"\<Method\>\"", "->", "\"\<Forward\>\""}]}], 
               "]"}]}], ";", "\n", "\t\t\t\t", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"A1Wmin", ",", "A2Wmin", ",", "A3Wmin"}], "}"}], "=", 
              RowBox[{"LeftInvariantDerivatives", "[", 
               RowBox[{"WPadded", ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
                RowBox[{"\"\<Method\>\"", "->", "\"\<Backward\>\""}]}], 
               "]"}]}], ";"}], "\n", "\t\t\t", ",", 
            RowBox[{"Goto", "[", "startComputingDerivatives", "]"}], ",", 
            RowBox[{"ListConvolve", "::", "ohp"}]}], "]"}], 
          RowBox[{"(*", 
           RowBox[{"end", " ", "of", " ", "Check"}], "*)"}], "\n", "\t\t", 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ListConvolve", "::", "ohp"}], ",", 
            RowBox[{"Transpose", "::", "tperm"}]}], "}"}]}], "]"}], ";", 
        RowBox[{"(*", 
         RowBox[{"end", " ", "of", " ", "Quiet"}], "*)"}], "\n", "\t\t", "\n",
         "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
          "*", "Squared", " ", 
          RowBox[{"(", "upwind", ")"}], " ", "derivatives"}], "*)"}], "\n", 
        "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"ordering", ":", " ", "1", ":", " ", 
           RowBox[{"xi", "-", "direction"}]}], ",", " ", 
          RowBox[{"2", ":", " ", 
           RowBox[{"eta", "-", "direction"}]}], ",", " ", 
          RowBox[{"3", ":", " ", 
           RowBox[{"theta", "-", "direction"}]}]}], "*)"}], "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{"Upwind", " ", 
          RowBox[{"scheme", ":"}]}], "*)"}], "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{"onlyForwardGearQ", ",", 
          RowBox[{"A1Wsquared", "=", 
           RowBox[{
            RowBox[{"Clip", "[", 
             RowBox[{
              RowBox[{"A1Wmin", "[", "\"\<Data\>\"", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "\[Infinity]"}], "}"}]}], "]"}], "^", 
            "2"}]}], ",", 
          RowBox[{
           RowBox[{"A1Wsquared", "=", 
            RowBox[{
             RowBox[{"UpwindDifferences", "[", 
              RowBox[{
               RowBox[{"A1Wmin", "[", "\"\<Data\>\"", "]"}], ",", 
               RowBox[{"A1Wplus", "[", "\"\<Data\>\"", "]"}]}], "]"}], "^", 
             "2"}]}], ";"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"A2Wsquared", "=", 
         RowBox[{
          RowBox[{"UpwindDifferences", "[", 
           RowBox[{
            RowBox[{"A2Wmin", "[", "\"\<Data\>\"", "]"}], ",", 
            RowBox[{"A2Wplus", "[", "\"\<Data\>\"", "]"}]}], "]"}], "^", 
          "2"}]}], ";", "\n", "\t\t", 
        RowBox[{"A3Wsquared", "=", 
         RowBox[{
          RowBox[{"UpwindDifferences", "[", 
           RowBox[{
            RowBox[{"A3Wmin", "[", "\"\<Data\>\"", "]"}], ",", 
            RowBox[{"A3Wplus", "[", "\"\<Data\>\"", "]"}]}], "]"}], "^", 
          "2"}]}], ";", "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
          "*", "Calculate", " ", "hamiltonian"}], "*)"}], "\n", "\t\t", 
        RowBox[{"H", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"A1Wsquared", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"sx", "^", "2"}], " ", 
                RowBox[{"\[Xi]", "^", "2"}]}], ")"}]}], "+", 
             RowBox[{"A2Wsquared", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"sx", "^", "2"}], " ", 
                RowBox[{"\[Epsilon]", "^", 
                 RowBox[{"(", 
                  RowBox[{"-", "2"}], ")"}]}], " ", 
                RowBox[{"\[Xi]", "^", "2"}]}], ")"}]}], "+", "A3Wsquared"}], 
            "]"}], "/", 
           RowBox[{"costPadded", "[", "\"\<Data\>\"", "]"}]}], "-", "1"}]}], 
        ";", "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
          "*", "Fix", " ", "the", " ", "origin"}], "*)"}], "\n", "\t\t", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"H", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"g0dList", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}], "+", "padsize"}], ",", 
              RowBox[{
               RowBox[{"g0dList", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", "padsize"}], ",", 
              RowBox[{"g0dList", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}], "]"}], "=", 
           "0."}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "g0dList", "]"}], ",", "1"}], "}"}]}], 
         "]"}], ";", "\n", "\t\t", 
        RowBox[{"Hmax", "=", 
         RowBox[{"Max", "[", 
          RowBox[{"Abs", "[", 
           RowBox[{"H", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"padsize", "+", "1"}], ";;", 
               RowBox[{
                RowBox[{"-", "padsize"}], "-", "1"}]}], ",", 
              RowBox[{
               RowBox[{"padsize", "+", "1"}], ";;", 
               RowBox[{
                RowBox[{"-", "padsize"}], "-", "1"}]}], ",", "All"}], "]"}], 
            "]"}], "]"}], "]"}]}], ";", "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
          "*", "Update", " ", "W"}], "*)"}], "\n", "\t\t", 
        RowBox[{"WPadded", "=", 
         RowBox[{"Affix", "[", 
          RowBox[{"WPadded", ",", 
           RowBox[{"\"\<Data\>\"", "->", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"WPadded", "[", "\"\<Data\>\"", "]"}], "-", 
              RowBox[{"deltat", "*", "H"}]}], ")"}]}]}], "]"}]}], ";", "\n", 
        "\t\t", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
          "*", "Next", " ", "iteration"}], "*)"}], "\n", "\t\t", 
        RowBox[{"it", "++"}], ";", "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
          "*", "Dynamic", " ", "update"}], "*)"}], "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{"SE2PDE`dynamicUpdate", ",", "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"SE2PDE`Hmax", "=", "Hmax"}], ";", "\n", "\t\t\t", 
           RowBox[{"SE2PDE`W", "=", 
            RowBox[{
             RowBox[{"WPadded", "[", "\"\<Data\>\"", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{
                RowBox[{"padsize", "+", "1"}], ";;", 
                RowBox[{
                 RowBox[{"-", "padsize"}], "-", "1"}]}], ",", 
               RowBox[{
                RowBox[{"padsize", "+", "1"}], ";;", 
                RowBox[{
                 RowBox[{"-", "padsize"}], "-", "1"}]}], ",", "All"}], "]"}], 
             "]"}]}], ";"}]}], "\n", "\t\t", "]"}], ";", "\n", "\t\t", "\n", 
        "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
          "*", "Safety", " ", "check"}], "*)"}], "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"Hmax", ">", 
           RowBox[{"10", "^", "20"}]}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";"}]}], "\n", "\t\t", "\n", 
      "\t\t", 
      RowBox[{"(*", 
       RowBox[{"End", " ", "of", " ", "While"}], "*)"}], "\n", "\t", "]"}], 
     ";", "\n", "\t", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Return", " ", "non"}], "-", 
       RowBox[{"padded", " ", "solution"}]}], "*)"}], "\n", "\t", 
     RowBox[{"Return", "[", 
      RowBox[{"Affix", "[", 
       RowBox[{"W", ",", 
        RowBox[{"\"\<Data\>\"", "->", 
         RowBox[{
          RowBox[{"WPadded", "[", "\"\<Data\>\"", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{
             RowBox[{"padsize", "+", "1"}], ";;", 
             RowBox[{
              RowBox[{"-", "padsize"}], "-", "1"}]}], ",", 
            RowBox[{
             RowBox[{"padsize", "+", "1"}], ";;", 
             RowBox[{
              RowBox[{"-", "padsize"}], "-", "1"}]}], ",", "All"}], "]"}], 
          "]"}]}]}], "]"}], "]"}]}]}], "\n", "]"}]}]], "Input",
 CellChangeTimes->{
  3.706952556001006*^9, {3.768620435932438*^9, 3.7686204443660684`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"f97615c9-b39b-4828-ae03-ed3f21a1f7c9"]
}, Closed]],

Cell[CellGroupData[{

Cell["Main II: Back tracking", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BackTracking", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"g1d_", ",", "g0d_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"A1WInt_", ",", "A2WInt_", ",", "A3WInt_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"beta_", ",", "epsilon_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"sTheta_", ",", "sx_"}], "}"}], ",", "periodicity_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\n", "\t", 
   RowBox[{
    RowBox[{"{", "\n", "\t\t", 
     RowBox[{"(*", 
      RowBox[{"Some", " ", "parameters"}], "*)"}], "\n", "\t\t", 
     RowBox[{
      RowBox[{"\[Delta]t", "=", "0.01"}], ",", 
      RowBox[{"(*", 
       RowBox[{"Step", " ", "size"}], "*)"}], "\n", "\t\t", 
      RowBox[{"minimumspeed", "=", 
       RowBox[{"10", "^", 
        RowBox[{"-", "3"}]}]}], ",", 
      RowBox[{"(*", 
       RowBox[{
       "Backtracking", " ", "stops", " ", "if", " ", "the", " ", "minimum", 
        " ", "speed", " ", "is", " ", "lower", " ", "than", " ", "this"}], 
       "*)"}], "\n", "\t\t", "\n", "\t\t", 
      RowBox[{"(*", "Initialization", "*)"}], "\n", "\t\t", 
      RowBox[{"direction", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", "\n", "\t\t", 
      "curved", ",", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"The", " ", "output", " ", "curve"}], ",", " ", 
        RowBox[{"d", " ", "stands", " ", "for", " ", "discrete"}]}], "*)"}], 
      "\n", "\t\t", "currentPoint", ",", "newPoint", ",", "\n", "\t\t", "\n", 
      "\t\t", 
      RowBox[{"(*", 
       RowBox[{"Gradient", " ", "descent", " ", "variables"}], "*)"}], "\n", 
      "\t\t", "A1", ",", "A2", ",", "A3", ",", "\n", "\t\t", "u1", ",", "u2", 
      ",", "u3"}], "\n", "\t", "}"}], ",", "\n", "\t", "\n", "\t", 
    RowBox[{"(*", 
     RowBox[{
     "Initialize", " ", "track", " ", "with", " ", "end", " ", "point"}], 
     "*)"}], "\n", "\t", 
    RowBox[{
     RowBox[{"curved", "=", 
      RowBox[{"{", "g1d", "}"}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"it", "=", "1"}], ";", "\n", "\t", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Norm", "[", "direction", "]"}], ">", "minimumspeed"}], "&&", 
        RowBox[{"it", "<", "10000"}]}], ",", "\n", "\t\t\t\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
          "Last"}], " ", "point"}], "*)"}], "\n", "\t\t", 
       RowBox[{
        RowBox[{"currentPoint", "=", 
         RowBox[{"curved", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}]}], ";", "\n", "\t\t", "\n", 
        "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
           "Gradient"}], " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{"left", " ", "invariant", " ", "vector", " ", "frame"}], 
         "*)"}], "\n", "\t\t", 
        RowBox[{"A1", "=", 
         RowBox[{"1", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"currentPoint", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
              "sTheta"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"currentPoint", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
              "sTheta"}], "]"}], ",", "0"}], "}"}]}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"xi", " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"A2", "=", 
         RowBox[{"1", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"currentPoint", "[", 
                  RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
               "sTheta"}], "]"}]}], ",", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"currentPoint", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
              "sTheta"}], "]"}], ",", "0"}], "}"}]}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"eta", " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"A3", "=", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"theta", " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"(*", "controls", "*)"}], "\n", "\t\t", 
        RowBox[{"u1", "=", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"sx", "^", "2"}], " ", 
             RowBox[{"beta", "^", "2"}]}], ")"}]}], "*", 
          RowBox[{"A1WInt", "[", 
           RowBox[{"Sequence", "@@", "currentPoint"}], "]"}]}]}], 
        RowBox[{"(*", 
         RowBox[{"division", " ", "by", " ", 
          RowBox[{"cost", "^", "2"}], " ", "is", " ", "included", " ", "in", 
          " ", "A1WInt"}], "*)"}], ";", "\n", "\t\t", 
        RowBox[{"u2", "=", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"epsilon", "^", 
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}]}], " ", 
             RowBox[{"sx", "^", "2"}], " ", 
             RowBox[{"beta", "^", "2"}]}], ")"}]}], "*", 
          RowBox[{"A2WInt", "[", 
           RowBox[{"Sequence", "@@", "currentPoint"}], "]"}]}]}], ";", "\n", 
        "\t\t", 
        RowBox[{"u3", "=", 
         RowBox[{
          RowBox[{"1", "/", "sTheta"}], " ", 
          RowBox[{"A3WInt", "[", 
           RowBox[{"Sequence", "@@", "currentPoint"}], "]"}]}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"Convert", " ", "to", " ", "discrete", " ", "angles"}], 
         "*)"}], "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{"Gradient", " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"direction", "=", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u1", "*", "A1"}], "+", 
            RowBox[{"u2", "*", "A2"}], "+", " ", 
            RowBox[{"u3", "*", "A3"}]}], ")"}]}]}], ";", "\n", "\t\t", "\n", 
        "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
           "Get"}], " ", "new", " ", "point", " ", "and", " ", "update", " ", 
          "curve"}], "*)"}], "\n", "\t\t", 
        RowBox[{"newPoint", "=", 
         RowBox[{"currentPoint", "+", 
          RowBox[{"\[Delta]t", "*", "direction"}]}]}], ";", "\n", "\t\t", 
        RowBox[{
         RowBox[{"newPoint", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "=", 
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"newPoint", "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"periodicity", "/", "sTheta"}], ",", "1"}], "]"}]}], ";", 
        "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"curved", ",", "newPoint"}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"curvedd", "=", "curved"}], ";", 
        RowBox[{"(*", 
         RowBox[{
         "Used", " ", "as", " ", "a", " ", "global", " ", "variable", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", ".", "t", ".", " ", "the"}], " ", "curve", " ", 
            "can", " ", "be", " ", "inspected", " ", "even", " ", "if", " ", 
            "the", " ", "code", " ", "was", " ", "aborted"}], ")"}]}], "*)"}],
         "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"it", "++"}], ";"}]}], "\n", "\t", "]"}], ";", "\n", "\t", 
     "\n", "\t", 
     RowBox[{"curved", "=", 
      RowBox[{"Reverse", "@", "curved"}]}], ";", "\n", "\t", 
     RowBox[{"Return", "[", "curved", "]"}], ";"}]}], "\n", "]"}]}]], "Input",
 CellLabel->"In[10]:=",ExpressionUUID->"a642502d-0e45-4204-beba-9345b49ec3bf"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
---Sub-Riemannian Wavefront propagation (iterative upwind scheme)\
\>", "Title",
 CellChangeTimes->{{3.7069489793781943`*^9, 3.706948983281579*^9}, {
  3.706953971158432*^9, 
  3.706953976950842*^9}},ExpressionUUID->"4636bc53-2b12-4735-ad28-\
a7773684e9ec"],

Cell[CellGroupData[{

Cell["1. Parameters", "Section",
 CellChangeTimes->{{3.7069489876031017`*^9, 3.706948987810665*^9}}],

Cell[CellGroupData[{

Cell["Parameters I: Volume and metric", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Spatial", " ", "dimensions"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"xyMinMax", "=", "4"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Physical", " ", "spatial", " ", "range"}], ",", " ", 
     RowBox[{
      RowBox[{"volume", " ", "runs", " ", "from"}], " ", "-", 
      RowBox[{"xyMinMax", " ", "to"}], " ", "+", "xyMinMax"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"gridScale", "=", "0.1"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"In", " ", "steps", " ", "of", " ", "\"\<gridScale\>\"", " ", 
     RowBox[{"(", 
      RowBox[{"smaller", " ", "means", " ", "more", " ", "detail"}], ")"}]}], 
    "*)"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Orientation", " ", 
     RowBox[{"sampling", ":"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"projective", "=", "False"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"True", ":", " ", 
      RowBox[{
      "theta", " ", "runs", " ", "from", " ", "0", " ", "to", " ", "1", " ", 
       "Pi"}]}], ",", " ", 
     RowBox[{"False", ":", " ", 
      RowBox[{"from", " ", "0", " ", "to", " ", "2", "Pi"}]}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"N\[Theta]", "=", "64"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.706948710962592*^9, 3.7069487110588493`*^9}, {
   3.706952511765313*^9, 3.7069525159103537`*^9}, 3.7069530700375156`*^9, 
   3.706953179477768*^9, 3.706953660520344*^9},
 CellLabel->"In[11]:=",ExpressionUUID->"ee12d98a-891c-468e-84c1-41f1ead3d17e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Metric", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Metric", ":"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", " ", "=", " ", "1.0"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Stiffness", " ", "parameter"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"\[Epsilon]", " ", "=", " ", ".1"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Anisotropy", " ", 
     RowBox[{"parameter", "/", "offway"}], " ", "penalization", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"for", " ", "sub"}], "-", 
        RowBox[{"Riemannian", " ", "case"}]}], ",", 
       RowBox[{"epsilon", "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"xi", "-"}], ")"}], "isotropic", " ", "Riemannian", " ", 
         "case", " ", "epsilon"}], "=", "1"}]}], ")"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"onlyForwardGearQ", "=", "False"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Note", ":", " ", 
     RowBox[{
     "With", " ", "only", " ", "forward", " ", "gear", " ", "we", " ", "need",
       " ", "2", "Pi", " ", "periodicity"}]}], "*)"}]}]}]], "Input",
 CellLabel->"In[15]:=",ExpressionUUID->"c8b5f844-0c91-48cb-bc87-86a168f68362"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derived variables", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Periodicity", " ", "and", " ", "angular", " ", 
    RowBox[{"resolution", ":"}]}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{"projective", ",", " ", 
      RowBox[{"periodicity", " ", "=", " ", "Pi"}], ",", " ", 
      RowBox[{"periodicity", " ", "=", " ", 
       RowBox[{"2", "Pi"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"s\[Theta]", " ", "=", " ", 
     RowBox[{"periodicity", "/", "N\[Theta]"}]}], ";"}], "  ", 
   RowBox[{"(*", 
    RowBox[{"Angular", " ", "resolution"}], "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"Spatial", " ", 
     RowBox[{"dimensions", ":"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Nx", ",", "Ny"}], "}"}], "=", 
     RowBox[{"Round", "@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"xyMinMax", "/", "gridScale"}]}], "+", "1"}], ",", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"xyMinMax", "/", "gridScale"}]}], "+", "1"}]}], "}"}]}]}], 
    ";"}]}]}]], "Input",
 CellLabel->"In[18]:=",ExpressionUUID->"f67b1376-e1b8-4456-b136-2e4a205b2bda"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Seed point", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Default", " ", "seed", " ", "point", " ", "at", " ", "the", " ", "center",
     " ", "of", " ", "the", " ", "volume"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Theta]0", "=", "0"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
    "orientation", " ", "in", " ", "real", " ", "world", " ", "coordinates"}],
     "*)"}], "\n", 
   RowBox[{
    RowBox[{"\[Theta]0d", "=", 
     RowBox[{"Mod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"\[Theta]0", "/", "s\[Theta]"}], "]"}], "+", "1"}], ",", 
       "N\[Theta]", ",", "1"}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"in", " ", "discrete", " ", "coordinates"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0d", ",", "y0d"}], "}"}], "=", 
     RowBox[{"Ceiling", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Nx", ",", "Ny"}], "}"}], "/", "2"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g0d", "=", 
     RowBox[{"{", 
      RowBox[{"x0d", ",", "y0d", ",", "\[Theta]0d"}], "}"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"coordinate", " ", "in", " ", "discrete", " ", "coordinates"}], 
    "*)"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Empty", " ", "image"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"im", "=", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{"1.", ",", 
       RowBox[{"{", 
        RowBox[{"Nx", ",", "Ny"}], "}"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellLabel->"In[21]:=",ExpressionUUID->"2c8b8083-11e9-42fc-b657-c230ce3f1b45"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Wavefront propagation (PDE solver)", "Section",
 CellChangeTimes->{{3.7069489915856686`*^9, 3.706948991937604*^9}}],

Cell[CellGroupData[{

Cell["\<\
Initialize W (create const cost function and W0 initialized as morphological \
delta)\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Constant", " ", "cost", " ", "function"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"cost", "=", 
     RowBox[{"ObjPositionOrientationData", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<Data\>\"", "->", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"1.", ",", 
           RowBox[{"{", 
            RowBox[{"Nx", ",", "Ny", ",", "N\[Theta]"}], "}"}]}], "]"}]}], 
        ",", 
        RowBox[{"\"\<Symmetry\>\"", "->", "periodicity"}]}], "}"}], "]"}]}], 
    ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Seed", " ", "point", 
     RowBox[{"(", "s", ")"}]}], "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"g0dList", "=", 
      RowBox[{"{", 
       RowBox[{"g0d", ",", 
        RowBox[{"g0d", "+", 
         RowBox[{"{", 
          RowBox[{"10", ",", "10", ",", "0"}], "}"}]}]}], "}"}]}], ";"}], 
    "*)"}], 
   RowBox[{"(*", 
    RowBox[{"<", 
     RowBox[{
      RowBox[{"--", "Multiple"}], " ", "seed", " ", 
      RowBox[{"points", "?"}]}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"g0dList", "=", "g0d"}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Initial", " ", "volume"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"W0", "=", 
     RowBox[{"OSInitialVolume", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Nx", ",", "Ny", ",", "N\[Theta]"}], "}"}], ",", "g0dList", 
       ",", "periodicity"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7686204480157113`*^9, 3.7686204497164974`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"15cfaf76-733b-411b-b60b-86f5a1cffea3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evolve W", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SE2NSolvePDEDynamicStatusOff", "[", "]"}], ";"}], "\n", 
 RowBox[{"SE2NSolvePDEDynamicStatus", "[", "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"W", "=", 
    RowBox[{"SRWaveFrontPropagation", "[", 
     RowBox[{
     "W0", ",", "cost", ",", "g0d", ",", "\[Xi]", ",", "\[Epsilon]", ",", 
      "s\[Theta]", ",", "gridScale", ",", "\[Infinity]", ",", 
      "onlyForwardGearQ"}], "]"}]}], ";"}], "//", 
  "AbsoluteTiming"}]}], "Input",
 CellLabel->"In[29]:=",ExpressionUUID->"fedcf25f-44c0-4404-b705-08c5b9564b90"],

Cell[BoxData[
 DynamicBox[ToBoxes[
   Column[{
     Dynamic[
      Row[{
       "---------   Max[Abs[hamiltonian]]: ", SE2PDE`Hmax, "   ---------"}]], 
     Row[{
       (Labeled[#, "Volume renderling"]& )[
        Framed[
         Dynamic[
          ImageAdjust[
           
           Image3D[-Transpose[SE2PDE`W, {2, 3, 1}], 
            ImageSize -> {400, 400}]]]]], 
       (Labeled[#, "Integral over theta"]& )[
        Framed[
         Dynamic[
          ImageAdjust[
           Image[
            Map[Total, SE2PDE`W, {2}], ImageSize -> {400, 400}]]]]], 
       (Labeled[#, "Minimum intensity projection over theta"]& )[
        Framed[
         Dynamic[
          ImageAdjust[
           Image[
            Map[Min, SE2PDE`W, {2}], ImageSize -> {400, 400}]]]]]}]}, 
    "Center"], StandardForm],
  ImageSizeCache->{1239., {220., 226.}}]], "Output",
 CellChangeTimes->{3.7686206789506063`*^9},
 ImageSize->{1243, 448},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[30]=",ExpressionUUID->"32832440-054b-4f91-b94c-02b03a5c0687"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"120.04922984660932`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.7686207990045853`*^9},
 ImageSize->{108, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[31]=",ExpressionUUID->"6681f77e-d0f4-4217-88d3-e5000fbee53a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Visualize level set", "Section",
 CellChangeTimes->{{3.7069489985772753`*^9, 3.706948999010435*^9}}],

Cell[CellGroupData[{

Cell["\<\
Construct interpolation function (with periodicity in theta direction)\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WInt", "=", 
  RowBox[{"ListInterpolation", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"W", "[", "\"\<Data\>\"", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"W", "[", "\"\<Data\>\"", "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "}"}]}], 
         "}"}], ",", "1"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "xyMinMax"}], ",", "xyMinMax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "xyMinMax"}], ",", "xyMinMax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "periodicity"}], "}"}]}], "}"}], ",", 
    RowBox[{"PeriodicInterpolation", "->", 
     RowBox[{"{", 
      RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[32]:=",ExpressionUUID->"d2dc45c6-f1ea-4852-bd9e-d58fd6db0895"],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{
       Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
       TemplateBox[{
         TemplateBox[{
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                  GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, 
                  ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "4.`"}], ",", "4.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "4.`"}], ",", "4.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}]}], 
                    "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                  GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, 
                  ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "4.`"}], ",", "4.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "4.`"}], ",", "4.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}]}], 
                    "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"3", ",", "3", ",", "3"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "True"}], "}"}], 
                    "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic]}, 
          "SummaryPanel"], 
         ButtonBox[
          DynamicBox[
           ToBoxes[
            If[
             
             Or[$VersionNumber < 11.2, CurrentValue["RunningEvaluator"] =!= 
              "Local"], 
             Style["This object cannot be used as input.", "SummaryEmbed"], 
             BoxForm`EmbedSummaryLabel[InterpolatingFunction, 6722360, 
              Dynamic[Typeset`embedState$$]]], StandardForm]], ButtonFunction :> 
          BoxForm`EmbedSummaryInterpretation[
           InterpolatingFunction, 
            8196322458487948682953479658628483336213217175207060275584, 
            EvaluationBox[], 
            Dynamic[Typeset`embedState$$], StandardForm], DefaultBaseStyle -> 
          "SummaryEmbedButton", BaseStyle -> {"DialogStyle"}, Enabled -> 
          Dynamic[
            And[$VersionNumber >= 11.2, CurrentValue["RunningEvaluator"] === 
             "Local", Typeset`embedState$$ === "Ready"]], Appearance -> 
          Inherited, Method -> Inherited, Evaluator -> Automatic]}, 
        "SummaryEmbedGrid"], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->(
    "InterpolatingFunction[{{-4., 4.}, {-4., 4.}, {\[Ellipsis], 0., 6.28319, \
\[Ellipsis]}}, <>]"& )],
  False,
  BoxID -> 8196322458487948682953479658628483336213217175207060275584,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.7686207995835075`*^9},
 ImageSize->{446, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[32]=",ExpressionUUID->"6ebc1161-155f-4eee-b4de-027a5c0483f7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show level set", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"levelset", "=", 
   RowBox[{"\[Pi]", "/", "2."}]}], ";"}], "\n", 
 RowBox[{"ContourPlot3D", "[", 
  RowBox[{
   RowBox[{"WInt", "[", 
    RowBox[{"x", ",", "y", ",", "\[Theta]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "xyMinMax"}], ",", "xyMinMax"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "xyMinMax"}], ",", "xyMinMax"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", 
     RowBox[{
      RowBox[{"-", "periodicity"}], "/", "2"}], ",", 
     RowBox[{"periodicity", "/", "2"}]}], "}"}], ",", 
   RowBox[{"Contours", "->", 
    RowBox[{"{", 
     RowBox[{"N", "@", "levelset"}], "}"}]}], ",", 
   RowBox[{"ContourStyle", "->", "Yellow"}], ",", 
   RowBox[{"PlotLabel", "->", "levelset"}]}], "]"}]}], "Input",
 CellLabel->"In[33]:=",ExpressionUUID->"ba88a86e-1408-4177-951c-206e9f5adf3e"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnWd7FFfWrp9z3i/n4/kL5zfgMDYYkwzYBmzjnHMrIZAJEklkhBAogITI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    "], {{0, 432}, {360, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 432},
  PlotRange->{{0, 360}, {0, 432}}]], "Output",
 CellChangeTimes->{3.768620809817005*^9},
 ImageSize->{364, 432},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[34]=",ExpressionUUID->"5bf956d2-3cfe-459f-8a82-45f8b95cff73"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Doing this for multiple level sets takes a long time! So we use the option \
PlotPoints->6 to reduce computation time. For more accurate renderings remove \
this option.\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
    RowBox[{"dw", "=", 
     RowBox[{"\[Pi]", "/", "8"}]}], ";", "\n", 
    RowBox[{"wmax", "=", 
     RowBox[{"3", "\[Pi]"}]}], ";", "\n", 
    RowBox[{"propagatingFronts", "=", 
     RowBox[{"Table", "[", "\n", 
      RowBox[{
       RowBox[{"ContourPlot3D", "[", 
        RowBox[{
         RowBox[{"WInt", "[", 
          RowBox[{"x", ",", "y", ",", "\[Theta]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "xMax"}], ",", "xMax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "yMax"}], ",", "yMax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", ",", 
           RowBox[{
            RowBox[{"-", "periodicity"}], "/", "2"}], ",", 
           RowBox[{"periodicity", "/", "2"}]}], "}"}], ",", 
         RowBox[{"Contours", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"N", "@", "levelset"}], "}"}]}], ",", 
         RowBox[{"ContourStyle", "\[Rule]", "Yellow"}], ",", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"PlotPoints", "\[Rule]", "6"}], ","}], "*)"}], 
         RowBox[{"PlotLabel", "\[Rule]", "levelset"}]}], "]"}], "\n", ",", 
       RowBox[{"{", 
        RowBox[{"levelset", ",", "dw", ",", "wmax", ",", "dw"}], "}"}]}], 
      "]"}]}], ";"}], "//", 
   RowBox[{"AbsoluteTiming", "\n", 
    RowBox[{"Manipulate", "[", 
     RowBox[{
      RowBox[{
      "propagatingFronts", "\[LeftDoubleBracket]", "wi", 
       "\[RightDoubleBracket]"}], ",", 
      RowBox[{"{", 
       RowBox[{"wi", ",", "1", ",", 
        RowBox[{"Length", "[", "propagatingFronts", "]"}], ",", "1"}], "}"}], 
      ",", 
      RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}]}], 
  "*)"}]], "Input",
 CellLabel->"In[35]:=",ExpressionUUID->"90615aae-cab4-484f-8dd0-4cada1dabcbf"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Back tracking", "Section",
 CellChangeTimes->{{3.7069490260018864`*^9, 
  3.706949026116188*^9}},ExpressionUUID->"c9e9e813-9994-46fc-8ee6-\
037099d78aa2"],

Cell[CellGroupData[{

Cell["Sink points", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"In", " ", "real", " ", "world", " ", "coordinates"}], "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"g1List", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.5", ",", "1.", ",", 
          RowBox[{"\[Pi]", "/", "3."}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1.5", ",", 
          RowBox[{"-", "1."}], ",", "0"}], "}"}]}], "}"}], "[", 
      RowBox[{"[", "All", "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"In", " ", "discrete", " ", "coordinates"}], "*)"}], "\n", 
   RowBox[{"g1dList", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"xyMinMax", "+", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "gridScale"}], "+",
          "1"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"xyMinMax", "+", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "gridScale"}], "+",
          "1"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "/", "s\[Theta]"}], "+", "1"}]}], 
       "}"}], "&"}], "/@", "g1List"}]}], "\n", 
   RowBox[{"(*", 
    RowBox[{"Show", " ", "setup"}], "*)"}], "\n", 
   RowBox[{"Show", "[", "\n", "\t", 
    RowBox[{
     RowBox[{"Image", "@", "im"}], ",", "\n", "\t", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", "Thick", ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
             RowBox[{"Nx", "-", 
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"g0d", "[", 
             RowBox[{"[", 
              RowBox[{"1", ";;", "2"}], "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"g0d", "[", 
              RowBox[{"[", 
               RowBox[{"1", ";;", "2"}], "]"}], "]"}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "im", "]"}], "/", "10"}], " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"g0d", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
                  "s\[Theta]"}], "]"}], ",", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"g0d", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
                  "s\[Theta]"}], "]"}]}], "}"}]}]}]}], "}"}]}], "]"}]}], 
       "}"}], "]"}], ",", "\n", "\t", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Flatten", "@", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Thick", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Arrow", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
                RowBox[{"Nx", "-", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], 
              "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"g1dList", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", 
                  RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"g1dList", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", 
                   RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Length", "[", "im", "]"}], "/", "10"}], " ", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"g1dList", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "3"}], "]"}], "]"}], "-", "1"}], ")"}], 
                    "*", "s\[Theta]"}], "]"}], ",", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"g1dList", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "3"}], "]"}], "]"}], "-", "1"}], ")"}], 
                    "*", "s\[Theta]"}], "]"}]}], "}"}]}]}]}], "}"}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "g1dList", "]"}], ",", "1"}], "}"}]}], 
          "]"}]}], "}"}]}], "]"}], ",", "\n", "\t", 
     RowBox[{"ImageSize", "->", "Medium"}], ",", 
     RowBox[{"Framed", "->", "True"}]}], "]"}]}]}]], "Input",
 CellLabel->"In[36]:=",ExpressionUUID->"a070417a-5adc-4ffd-a62d-ea8c4bb9ebef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"56.`", ",", "51.`", ",", "11.666666666666666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"56.`", ",", "31.`", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7686208101171284`*^9},
 ImageSize->{247, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[37]=",ExpressionUUID->"05ff3e4c-08ca-40cd-97f1-09ac06318544"],

Cell[BoxData[
 GraphicsBox[{RasterBox[CompressedData["
1:eJztyUEKQFAUBdCfgWzDHmQqS8AKvmKk1DeQXVsCYg1G59W9p9srx7WfsxDC
VtzVx71NKR5D/owpLnU1Pc/uy3tnQ5IkSZIkSZIkSZIkSZIkSZIkSZIkSZIk
SZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIk
SZIkSZIkSfI/L9qdX/I=
    "], {{0, 0}, {81, 81}}, {0., 1.},
    ColorFunction->GrayLevel], 
   {RGBColor[1, 0.5, 0], Thickness[Large], 
    ArrowBox[{{40.5, 40.5}, {40.5, 32.4}}]}, 
   {RGBColor[1, 0, 0], Thickness[Large], 
    ArrowBox[{{50.5, 25.5}, {57.51480577065395, 21.450000000000003`}}], 
    ArrowBox[{{30.5, 25.5}, {30.5, 17.400000000000006`}}]}},
  Framed -> True,
  ImageSize->Medium,
  PlotRange->{{0, 81}, {0, 81}}]], "Output",
 CellChangeTimes->{3.7686208101338897`*^9},
 ImageSize->{364, 360},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[38]=",ExpressionUUID->"ad30f538-713e-4dee-84ac-68f3a8f34cd5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prepare for backtracking (left-invariant derivatives)", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Calculate", " ", "finit", " ", "difference", " ", "derivatives"}],
    "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{"onlyForwardGearQ", ",", " ", 
      RowBox[{"A1W", "=", 
       RowBox[{
        RowBox[{"Clip", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"LeftInvariantDerivatives", "[", 
            RowBox[{"W", ",", "1", ",", 
             RowBox[{"\"\<Method\>\"", "->", "\"\<Central\>\""}]}], "]"}], 
           "[", "\"\<Data\>\"", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Infinity]"}], "}"}]}], "]"}], "/", 
        RowBox[{
         RowBox[{"cost", "[", "\"\<Data\>\"", "]"}], "^", "2"}]}]}], ",", " ", 
      RowBox[{"A1W", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"LeftInvariantDerivatives", "[", 
          RowBox[{"W", ",", "1", ",", 
           RowBox[{"\"\<Method\>\"", "->", "\"\<Central\>\""}]}], "]"}], "[", 
         "\"\<Data\>\"", "]"}], "/", 
        RowBox[{
         RowBox[{"cost", "[", "\"\<Data\>\"", "]"}], "^", "2"}]}]}]}], "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"A2W", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"LeftInvariantDerivatives", "[", 
        RowBox[{"W", ",", "2", ",", 
         RowBox[{"\"\<Method\>\"", "->", "\"\<Central\>\""}]}], "]"}], "[", 
       "\"\<Data\>\"", "]"}], "/", 
      RowBox[{
       RowBox[{"cost", "[", "\"\<Data\>\"", "]"}], "^", "2"}]}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"A3W", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"LeftInvariantDerivatives", "[", 
        RowBox[{"W", ",", "3", ",", 
         RowBox[{"\"\<Method\>\"", "->", "\"\<Central\>\""}]}], "]"}], "[", 
       "\"\<Data\>\"", "]"}], "/", 
      RowBox[{
       RowBox[{"cost", "[", "\"\<Data\>\"", "]"}], "^", "2"}]}]}], ";"}], 
   "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"--", "--"}], "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"Interpolated", " ", "functions"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"periodicity", "==", 
       RowBox[{"2", "\[Pi]"}]}], ",", "\n", "\t", 
      RowBox[{
       RowBox[{"A1WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A1W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"A1W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"periodicity", "/", "s\[Theta]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";", "\n", "\t", 
       RowBox[{"A2WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A2W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"A2W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"periodicity", "/", "s\[Theta]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";", "\n", "\t", 
       RowBox[{"A3WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A3W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"A3W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"periodicity", "/", "s\[Theta]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";"}], "\n", ",", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"if", " ", "periodicity"}], "\[Equal]", "\[Pi]"}], "*)"}], 
      "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{
       "Here", " ", "minus", " ", "the", " ", "copy", " ", "of", " ", "0", 
        " ", "to", " ", "pi", " ", "because", " ", "A1", " ", "and", " ", 
        "A2", " ", "are", " ", "in", " ", "opposite", " ", 
        RowBox[{"directions", ":"}]}], "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{"A1WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A1W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"-", 
                 RowBox[{"Transpose", "[", 
                  RowBox[{"A1W", ",", 
                   RowBox[{"{", 
                    RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"A1W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"2", 
                RowBox[{"periodicity", "/", "s\[Theta]"}]}]}]}], "}"}]}], 
           "}"}], ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";", "\n", "\t", 
       RowBox[{"A2WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A2W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"-", 
                 RowBox[{"Transpose", "[", 
                  RowBox[{"A2W", ",", 
                   RowBox[{"{", 
                    RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"A2W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"2", 
                RowBox[{"periodicity", "/", "s\[Theta]"}]}]}]}], "}"}]}], 
           "}"}], ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";", "\n", "\t", 
       RowBox[{"A3WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A3W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"A3W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"periodicity", "/", "s\[Theta]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";"}]}], "\n", "]"}], ";"}]}]}]], "Input",
 CellLabel->"In[39]:=",ExpressionUUID->"dd568326-9ba3-4c7f-bc96-d1d599506d69"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The actual backtracking", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"curvesd", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"BackTracking", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", "g0d"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"A1WInt", ",", "A2WInt", ",", "A3WInt"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Xi]", ",", "\[Epsilon]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"s\[Theta]", ",", "gridScale"}], "}"}], ",", "periodicity"}],
        "]"}], "&"}], "/@", "g1dList"}]}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{"Show", " ", "results"}], "*)"}]}], "\n", 
 RowBox[{"resultsUpwind", "=", 
  RowBox[{"Show", "[", "\n", "\t", 
   RowBox[{
    RowBox[{"ImageAdjust", "@", 
     RowBox[{"Image", "[", 
      RowBox[{"Map", "[", 
       RowBox[{"Min", ",", 
        RowBox[{"W", "[", "\"\<Data\>\"", "]"}], ",", 
        RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], ",", "\n", "\t", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{"Graphics", "[", " ", 
       RowBox[{"{", 
        RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
         RowBox[{"Line", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
              RowBox[{"Nx", "-", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], "&"}], 
           "/@", 
           RowBox[{"curvesd", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "}"}], " ", "]"}], ",",
       " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "curvesd", "]"}], ",", "1"}], "}"}]}], " ", 
     "]"}], ",", "\n", "\t", 
    RowBox[{"ImageSize", "->", "Medium"}], ",", 
    RowBox[{"Frame", "->", "False"}], ",", 
    RowBox[{"Framed", "->", "True"}]}], "]"}]}]}], "Input",
 CellLabel->"In[43]:=",ExpressionUUID->"417bae8b-954b-452b-bb4e-4cb28e8edaa3"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnQnYlVXV/s0c0740MbX0U9NUVAqcEVBBYlAUGRJBIF+QGQEZBARFSw2T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    "], {{0, 360}, {360, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 360},
  PlotRange->{{0, 360}, {0, 360}}]], "Output",
 CellChangeTimes->{3.7686208127579927`*^9},
 ImageSize->{364, 360},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[44]=",ExpressionUUID->"af7ce2ea-73a8-4be8-8968-d4d4fa8d7d1f"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["---Exercises", "Title",
 CellChangeTimes->{{3.706949038114141*^9, 3.706949040818341*^9}, {
  3.7069537459725857`*^9, 3.70695374629344*^9}}],

Cell[CellGroupData[{

Cell["\<\
1. Try to find different types of geodesics (U-curves, S-curves, curves with \
cusps)\
\>", "Section",
 CellChangeTimes->{{3.7069490456491537`*^9, 3.706949099234742*^9}}],

Cell[CellGroupData[{

Cell["Manipulate for interactive backtracking:", "Subsection",
 CellChangeTimes->{{3.7069490487394123`*^9, 3.706949049170561*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Function", " ", "for", " ", "coordinate", " ", "conversion"}], 
   "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"SaveElement", "[", 
     RowBox[{"xReal_", ",", "\[Theta]Real_", ",", 
      RowBox[{"{", 
       RowBox[{"dimx_", ",", "dimy_"}], "}"}], ",", "s\[Theta]_", ",", 
      "periodicity_"}], "]"}], ":=", 
    RowBox[{"{", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"Real", " ", "coordinates"}], "*)"}], "\n", "\t", 
     RowBox[{
      RowBox[{"Flatten", "@", 
       RowBox[{"{", 
        RowBox[{"xReal", ",", "\[Theta]Real"}], "}"}]}], ",", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{"Array", " ", "coordinates"}], "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "dimx", ",", "1"}], "]"}], 
          ",", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "dimy", ",", "1"}], "]"}], 
          ",", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", 
            RowBox[{"periodicity", "/", "s\[Theta]"}], ",", "1"}], "]"}]}], 
         "}"}], "&"}], "@", 
       RowBox[{"Round", "@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"dimx", "-", 
           RowBox[{"xReal", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "+", "0.5"}], ",", 
          RowBox[{
           RowBox[{"xReal", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}], ",", 
          RowBox[{
           RowBox[{"\[Theta]Real", "/", "s\[Theta]"}], "+", "1"}]}], 
         "}"}]}]}]}], "\n", "\t", "}"}]}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Interactive", " ", "tracking"}], "*)"}], "\n", 
   RowBox[{"Manipulate", "[", "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"(", "\n", "\t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"g1", ",", "g1d"}], "}"}], "=", 
         RowBox[{"SaveElement", "[", 
          RowBox[{"xtemp", ",", "\[Theta]temp", ",", 
           RowBox[{"Dimensions", "[", "im", "]"}], ",", "s\[Theta]", ",", 
           RowBox[{"(", "periodicity", ")"}]}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"curved", "=", 
         RowBox[{"BackTracking", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"g1d", ",", "g0d"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"A1WInt", ",", "A2WInt", ",", "A3WInt"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Xi]", ",", "\[Epsilon]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"s\[Theta]", ",", "gridScale"}], "}"}], ",", 
           "periodicity"}], "]"}]}], ";"}], "\n", "\t", ")"}], ";", "\n", 
      "\t", 
      RowBox[{"Framed", "@", 
       RowBox[{"Show", "[", "\n", "\t\t", 
        RowBox[{
         RowBox[{"Image", "[", "im", "]"}], ",", "\n", "\t\t", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Thick", ",", 
            RowBox[{"Arrow", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
                 RowBox[{"Nx", "-", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], 
               "&"}], "/@", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"curvedd", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", 
                   RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"curvedd", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Length", "[", "cost", "]"}], "/", "10"}], "*", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"curvedd", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "3"}], "]"}], "]"}], "-", "1"}], 
                    ")"}], "*", "s\[Theta]"}], "]"}], ",", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"curvedd", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "3"}], "]"}], "]"}], "-", "1"}], 
                    ")"}], "*", "s\[Theta]"}], "]"}]}], "}"}]}]}]}], "}"}]}], 
             "]"}]}], "}"}], "]"}], ",", "\n", "\t\t", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", "Thick", ",", 
            RowBox[{"Arrow", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
                 RowBox[{"Nx", "-", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], 
               "&"}], "/@", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"curvedd", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", 
                   RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"curvedd", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", 
                    RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Length", "[", "cost", "]"}], "/", "10"}], "*", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"curvedd", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", "1"}], ")"}], 
                    "*", "s\[Theta]"}], "]"}], ",", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"curvedd", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", "1"}], ")"}], 
                    "*", "s\[Theta]"}], "]"}]}], "}"}]}]}]}], "}"}]}], 
             "]"}]}], "}"}], "]"}], ",", "\n", "\t\t", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Green", ",", "Thick", ",", 
            RowBox[{"Line", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
                 RowBox[{"Nx", "-", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], 
               "&"}], "/@", "curvedd"}], "]"}]}], "}"}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{"ImageSize", "->", "600"}], ",", 
         RowBox[{"Frame", "->", "False"}]}], "]"}]}]}], ",", "\n", "\t", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xtemp", ",", 
         RowBox[{"{", 
          RowBox[{"84.4", ",", "79.7"}], "}"}]}], "}"}], ",", "Locator"}], 
      "}"}], ",", "\n", "\t", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]temp", ",", "0"}], "}"}], ",", "0", ",", 
       RowBox[{"periodicity", "-", "s\[Theta]"}], ",", "s\[Theta]"}], "}"}]}],
     "\n", "\t", 
    RowBox[{"(*", 
     RowBox[{",", 
      RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "*)"}], 
    RowBox[{"(*", 
     RowBox[{"<", 
      RowBox[{
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", "Save"}]}]}]}], " ", "definitions", " ", "and", " ", 
       "save", " ", "selection", " ", "as", " ", "cdf", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"File", ">", 
          RowBox[{"CDF", " ", "Export"}], ">", "Standalone"}], ".."}], 
        ")"}]}]}], "*)"}], "\n", "]"}]}]}]], "Input",
 CellLabel->"In[45]:=",ExpressionUUID->"9818ad77-d301-4e69-9f04-226fd5035f81"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Try to find Maxwell points and plot the two geodesics arriving at the \
Maxwell point by specifying 2 end-conditions with slightly different end-angle\
\>", "Section",
 CellChangeTimes->{{3.706949106066891*^9, 3.7069491488827887`*^9}}],

Cell[TextData[{
 StyleBox["Note",
  FontWeight->"Bold"],
 ": the 2 Maxwell surfaces are given by x Cos[\[Theta]/2]+y \
Sin[\[Theta]/2]==0 and | \[Theta] |=\[Pi]"
}], "Text",
 CellChangeTimes->{{3.706949292418666*^9, 3.706949321540122*^9}, {
  3.70695334967058*^9, 3.70695335147735*^9}, {3.7069534509650307`*^9, 
  3.7069534556705403`*^9}, {3.706953549061846*^9, 3.706953580087393*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"In", " ", "real", " ", "world", " ", "coordinates"}], "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"g1List", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2.5", ",", "2.5", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}], "-", 
          RowBox[{"s\[Theta]", "/", "4"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.5", ",", "2.5", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}], "+", 
          RowBox[{"s\[Theta]", "/", "8"}]}]}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"Some", " ", "other", " ", "Maxwell", " ", "points"}], "*)"}], 
   "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"g1List", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5", ",", 
          RowBox[{
           RowBox[{"-", "s\[Theta]"}], "/", "2"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5", ",", 
          RowBox[{
           RowBox[{"+", "s\[Theta]"}], "/", "2"}]}], "}"}]}], "}"}]}], ";", 
     "\n", 
     RowBox[{"g1List", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2.5", ",", "0.", ",", 
          RowBox[{"\[Pi]", "-", 
           RowBox[{"s\[Theta]", "/", "2"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2.5", ",", "0.", ",", 
          RowBox[{"\[Pi]", "+", 
           RowBox[{"s\[Theta]", "/", "2"}]}]}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"g1List", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2.5", ",", "2.5", ",", 
          RowBox[{"\[Pi]", "-", 
           RowBox[{"s\[Theta]", "/", "4"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2.5", ",", "2.5", ",", 
          RowBox[{"\[Pi]", "+", 
           RowBox[{"s\[Theta]", "/", "8"}]}]}], "}"}]}], "}"}]}], ";"}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"In", " ", "discrete", " ", 
     RowBox[{"(", "array", ")"}], " ", "coordinates"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"g1dList", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"xyMinMax", "+", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "gridScale"}], "+",
          "1"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"xyMinMax", "+", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "gridScale"}], "+",
          "1"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "/", "s\[Theta]"}], "+", "1"}]}], 
       "}"}], "&"}], "/@", "g1List"}]}], "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Back", " ", "tracking"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"curvesd", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"BackTracking", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#", ",", "g0d"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"A1WInt", ",", "A2WInt", ",", "A3WInt"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Xi]", ",", "\[Epsilon]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"s\[Theta]", ",", "gridScale"}], "}"}], ",", 
         "periodicity"}], "]"}], "&"}], "/@", "g1dList"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Show", " ", "results"}], "*)"}], "\n", 
   RowBox[{"resultsUpwind", "=", 
    RowBox[{"Show", "[", "\n", "\t", 
     RowBox[{
      RowBox[{"ImageAdjust", "@", 
       RowBox[{"Image", "[", 
        RowBox[{"Map", "[", 
         RowBox[{"Min", ",", 
          RowBox[{"W", "[", "\"\<Data\>\"", "]"}], ",", 
          RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], ",", "\n", "\t", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{"Graphics", "[", " ", 
         RowBox[{"{", 
          RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
           RowBox[{"Line", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
                RowBox[{"Nx", "-", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], 
              "&"}], "/@", 
             RowBox[{"curvesd", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "}"}], " ", "]"}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "curvesd", "]"}], ",", "1"}], "}"}]}], " ", 
       "]"}], ",", "\n", "\t", 
      RowBox[{"ImageSize", "->", "Medium"}], ",", 
      RowBox[{"Frame", "->", "False"}], ",", 
      RowBox[{"Framed", "->", "True"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.70694942901003*^9, 3.706949456679658*^9}, {
  3.706949491266674*^9, 3.706949537332206*^9}, {3.7069495768503375`*^9, 
  3.706949579459299*^9}, {3.7069496106753244`*^9, 3.7069496484327745`*^9}, {
  3.706949699025367*^9, 3.706949768435051*^9}, {3.706949804099928*^9, 
  3.706949826978793*^9}, {3.706949881356465*^9, 3.7069498838430767`*^9}, {
  3.7069499233983145`*^9, 3.7069500191239805`*^9}, {3.7069529656848726`*^9, 
  3.7069529691119914`*^9}, {3.706953036728874*^9, 3.70695303938093*^9}, {
  3.706953263732918*^9, 3.7069533395576706`*^9}, {3.7069536317839174`*^9, 
  3.706953639301922*^9}, {3.7069537639902887`*^9, 3.7069537780226183`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"4c084279-876c-471c-a707-7fe8759f9e02"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"66.`", ",", "66.`", ",", 
     RowBox[{"-", 
      FractionBox["61", "4"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"66.`", ",", "66.`", ",", 
     RowBox[{"-", 
      FractionBox["119", "8"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7686208130676517`*^9},
 ImageSize->{253, 38},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[48]=",ExpressionUUID->"9ffea176-b555-4c97-8ff9-698226fc6a56"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnQe01cW1xk00sSXGKEkwMYpdgyY2LCg2LEhsqEgRUJAmHS7lUi69C6Ji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    "], {{0, 360}, {360, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 360},
  PlotRange->{{0, 360}, {0, 360}}]], "Output",
 CellChangeTimes->{3.768620813317586*^9},
 ImageSize->{364, 360},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[50]=",ExpressionUUID->"ef73aa45-dee1-485c-81fd-3a8e43662e85"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["---End of notebook", "Title",
 CellChangeTimes->{{3.706953695204878*^9, 3.7069536983412037`*^9}}],

Cell[CellGroupData[{

Cell["Convert output to bitmap to reduce notebook size", "Section",
 CellChangeTimes->{{3.631265495696987*^9, 3.6312654995601997`*^9}, {
  3.706939152123087*^9, 3.706939156026475*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Run", " ", "to", " ", "convert", " ", "all", " ", "image", " ", "output", 
    " ", "to", " ", "bitmap"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"NotebookFind", "[", 
     RowBox[{
      RowBox[{"InputNotebook", "[", "]"}], ",", "\"\<Output\>\"", ",", "All", 
      ",", "CellStyle"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"FrontEndTokenExecute", "[", 
     RowBox[{
      RowBox[{"InputNotebook", "[", "]"}], ",", "\"\<SelectionConvert\>\"", 
      ",", "\"\<BitmapConditional\>\""}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.615614680193201*^9, 3.615614720877468*^9}},
 CellLabel->"In[51]:=",
 CellID->133026008,ExpressionUUID->"3004f550-f6c8-4dbb-8329-e23e6a937d21"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 1117},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
InputAliases->{"intt" -> RowBox[{"\[Integral]", 
     RowBox[{"\[SelectionPlaceholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "dintt" -> RowBox[{
     SubsuperscriptBox[
     "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
     RowBox[{"\[Placeholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "sumt" -> RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "prodt" -> RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "dt" -> RowBox[{
     SubscriptBox["\[PartialD]", "\[Placeholder]"], " ", 
     "\[SelectionPlaceholder]"}], "ia" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Inactive"], "cbrt" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "3", SurdForm -> True, MultilineFunction -> 
    None], "surd" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "\[Placeholder]", SurdForm -> True, 
    MultilineFunction -> None], "ket" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Ket"], "bra" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Bra"], "braket" -> 
  TemplateBox[{"\[SelectionPlaceholder]", "\[Placeholder]"}, "BraKet"], 
  "delay" -> TemplateBox[{"\[SelectionPlaceholder]"}, "SystemsModelDelay"], 
  "grad" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Placeholder]"}], 
  "del." -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], ".", 
     "\[Placeholder]"}], "delx" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Cross]", 
     "\[Placeholder]"}], "del2" -> RowBox[{
     SubsuperscriptBox["\[Del]", "\[SelectionPlaceholder]", 2], 
     "\[Placeholder]"}], "notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation>" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation<" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "symb" -> RowBox[{"Symbolize", "[", 
     TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], "]"}], 
  "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], ",", 
       "\[Placeholder]"}], "]"}], "addia" -> RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[SelectionPlaceholder]\"", "\[Rule]", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "pattwraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationPatternTag"], 
  "madeboxeswraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationMadeBoxesTag"], "=<" -> 
  OverscriptBox["=", "\:02c2"], ":=<" -> OverscriptBox[":=", "\:02c2"]},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 98, 1, 96, "Title",ExpressionUUID->"731c55cd-e86d-4535-8bf2-b0c00f7cf585"],
Cell[CellGroupData[{
Cell[703, 27, 112, 1, 67, "Section",ExpressionUUID->"c0fbd549-699b-477b-8a9b-ec3e51616591"],
Cell[818, 30, 627, 15, 48, "Input",ExpressionUUID->"3fc1d014-3a54-4492-b5b1-4a5fbdf8af73"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1494, 51, 99, 1, 96, "Title",ExpressionUUID->"d2a69121-3141-4949-807a-8199e7acec24"],
Cell[CellGroupData[{
Cell[1618, 56, 88, 2, 67, "Section",ExpressionUUID->"d4b74ebb-2218-4ea7-b53a-2472694b39eb"],
Cell[CellGroupData[{
Cell[1731, 62, 48, 0, 53, "Subsection",ExpressionUUID->"a50a4806-0a29-46a0-b571-5bc7ad00b18e"],
Cell[1782, 64, 2794, 74, 257, "Input",ExpressionUUID->"2ce70a5e-a2f4-4dd1-903a-b9900d162b3d"]
}, Closed]],
Cell[CellGroupData[{
Cell[4613, 143, 75, 0, 37, "Subsection",ExpressionUUID->"9514dd5c-fb22-47e2-b6e5-6097f57a23cc"],
Cell[4691, 145, 7577, 186, 732, "Input",ExpressionUUID->"d25c5248-bc1a-47ed-ad1a-5b02a02e76d6"]
}, Closed]],
Cell[CellGroupData[{
Cell[12305, 336, 47, 0, 37, "Subsection",ExpressionUUID->"6c2f16b8-4300-4f21-982e-0dddf6fa4011"],
Cell[12355, 338, 1321, 38, 50, "Input",ExpressionUUID->"e95d1627-6a0a-4b05-88b8-15cdd3ec1623"]
}, Closed]],
Cell[CellGroupData[{
Cell[13713, 381, 50, 0, 37, "Subsection",ExpressionUUID->"b25b7f85-4f21-47a0-8c17-0db4f9a309b5"],
Cell[CellGroupData[{
Cell[13788, 385, 46, 0, 39, "Subsubsection",ExpressionUUID->"6c5c8265-1e67-444c-93e8-a1f69fa1f8e9"],
Cell[13837, 387, 3375, 83, 240, "Input",ExpressionUUID->"530fac99-326c-4ce2-9483-27ae2aa071d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17249, 475, 50, 0, 39, "Subsubsection",ExpressionUUID->"e98e8416-3410-4503-bd24-8e17f37ec66f"],
Cell[17302, 477, 328, 9, 30, "Input",ExpressionUUID->"43bf2da6-9a42-41b3-8e33-f9c9c22b1cad"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[17691, 493, 63, 0, 53, "Section",ExpressionUUID->"abe4e72d-eaf2-46ae-abed-2c65fdadebfa"],
Cell[17757, 495, 14917, 362, 1473, "Input",ExpressionUUID->"f97615c9-b39b-4828-ae03-ed3f21a1f7c9"]
}, Closed]],
Cell[CellGroupData[{
Cell[32711, 862, 41, 0, 53, "Section",ExpressionUUID->"a0caac1d-3d2e-4d8a-b5c5-76b5041e2561"],
Cell[32755, 864, 8192, 203, 943, "Input",ExpressionUUID->"a642502d-0e45-4204-beba-9345b49ec3bf"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40996, 1073, 267, 6, 96, "Title",ExpressionUUID->"4636bc53-2b12-4735-ad28-a7773684e9ec"],
Cell[CellGroupData[{
Cell[41288, 1083, 100, 1, 67, "Section",ExpressionUUID->"00bafac2-c801-4249-9967-9dba60c4ed31"],
Cell[CellGroupData[{
Cell[41413, 1088, 53, 0, 53, "Subsection",ExpressionUUID->"3aedf4eb-b2d8-44c8-ba68-7a2b2e9d87cf"],
Cell[41469, 1090, 1497, 38, 143, "Input",ExpressionUUID->"ee12d98a-891c-468e-84c1-41f1ead3d17e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43003, 1133, 28, 0, 53, "Subsection",ExpressionUUID->"b4de5ea6-83ef-4c27-973d-d167c38dedd9"],
Cell[43034, 1135, 1185, 32, 105, "Input",ExpressionUUID->"c8b5f844-0c91-48cb-bc87-86a168f68362"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44256, 1172, 39, 0, 53, "Subsection",ExpressionUUID->"7f9415fd-c4dd-4d21-99eb-5e65094276d0"],
Cell[44298, 1174, 1184, 34, 105, "Input",ExpressionUUID->"f67b1376-e1b8-4456-b136-2e4a205b2bda"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45519, 1213, 32, 0, 53, "Subsection",ExpressionUUID->"b4c26f81-61a3-4c11-9e0a-e02f8539b6f5"],
Cell[45554, 1215, 1559, 46, 162, "Input",ExpressionUUID->"2c8b8083-11e9-42fc-b657-c230ce3f1b45"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47162, 1267, 124, 1, 67, "Section",ExpressionUUID->"816d2f44-cc3a-476e-8b1d-f89385d4c1ce"],
Cell[CellGroupData[{
Cell[47311, 1272, 115, 3, 53, "Subsection",ExpressionUUID->"e9c51a11-9161-470f-ba8a-3fbb7d8cf083"],
Cell[47429, 1277, 1609, 47, 181, "Input",ExpressionUUID->"15cfaf76-733b-411b-b60b-86f5a1cffea3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49075, 1329, 30, 0, 53, "Subsection",ExpressionUUID->"49ef23e4-3047-416e-9c72-830ff64064fb"],
Cell[CellGroupData[{
Cell[49130, 1333, 551, 13, 67, "Input",ExpressionUUID->"fedcf25f-44c0-4404-b705-08c5b9564b90"],
Cell[49684, 1348, 1070, 32, 465, "Output",ExpressionUUID->"32832440-054b-4f91-b94c-02b03a5c0687"],
Cell[50757, 1382, 305, 7, 32, "Output",ExpressionUUID->"6681f77e-d0f4-4217-88d3-e5000fbee53a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51123, 1396, 109, 1, 67, "Section",ExpressionUUID->"35940dbc-5a63-4d95-b464-9b8bf5763de1"],
Cell[CellGroupData[{
Cell[51257, 1401, 100, 2, 53, "Subsection",ExpressionUUID->"b871b57a-0323-4fa6-9e64-260863c68b34"],
Cell[CellGroupData[{
Cell[51382, 1407, 1309, 37, 28, "Input",ExpressionUUID->"d2dc45c6-f1ea-4852-bd9e-d58fd6db0895"],
Cell[52694, 1446, 11419, 232, 90, "Output",ExpressionUUID->"6ebc1161-155f-4eee-b4de-027a5c0483f7"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[64162, 1684, 36, 0, 53, "Subsection",ExpressionUUID->"9f64dc4a-386a-4f3a-88e8-e589528c54e4"],
Cell[CellGroupData[{
Cell[64223, 1688, 900, 24, 48, "Input",ExpressionUUID->"ba88a86e-1408-4177-951c-206e9f5adf3e"],
Cell[65126, 1714, 17848, 299, 449, "Output",ExpressionUUID->"5bf956d2-3cfe-459f-8a82-45f8b95cff73"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[83023, 2019, 199, 4, 53, "Subsection",ExpressionUUID->"01aed729-3fdb-48d0-9f70-eaeac0cfb392"],
Cell[83225, 2025, 1866, 49, 124, "Input",ExpressionUUID->"90615aae-cab4-484f-8dd0-4cada1dabcbf"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85140, 2080, 163, 3, 67, "Section",ExpressionUUID->"c9e9e813-9994-46fc-8ee6-037099d78aa2"],
Cell[CellGroupData[{
Cell[85328, 2087, 33, 0, 53, "Subsection",ExpressionUUID->"a2edad69-2e96-4da1-bef5-9aa39d84613f"],
Cell[CellGroupData[{
Cell[85386, 2091, 5445, 149, 200, "Input",ExpressionUUID->"a070417a-5adc-4ffd-a62d-ea8c4bb9ebef"],
Cell[90834, 2242, 432, 11, 32, "Output",ExpressionUUID->"05ff3e4c-08ca-40cd-97f1-09ac06318544"],
Cell[91269, 2255, 892, 20, 377, "Output",ExpressionUUID->"ad30f538-713e-4dee-84ac-68f3a8f34cd5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[92210, 2281, 75, 0, 53, "Subsection",ExpressionUUID->"9bd4ae12-7421-4ed2-bff6-0a83f29d55cc"],
Cell[92288, 2283, 11274, 297, 333, "Input",ExpressionUUID->"dd568326-9ba3-4c7f-bc96-d1d599506d69"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103599, 2585, 45, 0, 53, "Subsection",ExpressionUUID->"8fe5a5e9-5a2c-4a9e-b6c8-44db63133e26"],
Cell[CellGroupData[{
Cell[103669, 2589, 2028, 55, 124, "Input",ExpressionUUID->"417bae8b-954b-452b-bb4e-4cb28e8edaa3"],
Cell[105700, 2646, 19334, 323, 377, "Output",ExpressionUUID->"af7ce2ea-73a8-4be8-8968-d4d4fa8d7d1f"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[125107, 2977, 145, 2, 96, "Title",ExpressionUUID->"b6678ca2-85ac-4a35-87ae-a921591fab43"],
Cell[CellGroupData[{
Cell[125277, 2983, 180, 4, 67, "Section",ExpressionUUID->"1161648b-3550-4453-abc1-c5341bc1f3a7"],
Cell[CellGroupData[{
Cell[125482, 2991, 130, 1, 53, "Subsection",ExpressionUUID->"044e2418-e481-4f8f-abd0-0613a5b288b4"],
Cell[125615, 2994, 8895, 231, 466, "Input",ExpressionUUID->"9818ad77-d301-4e69-9f04-226fd5035f81"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[134559, 3231, 248, 4, 67, "Section",ExpressionUUID->"a40a6063-aab2-41a8-93b8-d9f2bd36adc2"],
Cell[134810, 3237, 385, 8, 34, "Text",ExpressionUUID->"c3cf57c7-fad3-4d75-a0a5-8ac2e3a3b4cb"],
Cell[CellGroupData[{
Cell[135220, 3249, 5857, 157, 371, "Input",ExpressionUUID->"4c084279-876c-471c-a707-7fe8759f9e02"],
Cell[141080, 3408, 509, 15, 55, "Output",ExpressionUUID->"9ffea176-b555-4c97-8ff9-698226fc6a56"],
Cell[141592, 3425, 21081, 352, 377, "Output",ExpressionUUID->"ef73aa45-dee1-485c-81fd-3a8e43662e85"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[162734, 3784, 103, 1, 96, "Title",ExpressionUUID->"da8d6127-464b-4454-a733-415c944b372d"],
Cell[CellGroupData[{
Cell[162862, 3789, 184, 2, 67, "Section",ExpressionUUID->"b9ffee73-a1bb-492e-8bfe-c3cb43c1711d"],
Cell[163049, 3793, 772, 19, 67, "Input",ExpressionUUID->"3004f550-f6c8-4dbb-8329-e23e6a937d21",
 CellID->133026008]
}, Open  ]]
}, Open  ]]
}
]
*)

